<?php
#######################################
## (inv) Awards #######################
#######################################
## Author:  Alec Carpenter
## Website: http://www.invisionenvy.com
#######################################
##                               PUBLIC
## Module:  AWARDS
## Section: AWARDS
#######################################
## VERSION: 2.2.3 BETA 1
#######################################

if (!defined('IN_IPB'))
{
	print "<h1>Incorrect access</h1>You cannot access this file directly. If you have recently upgraded, make sure you upgraded all the relevant files.";
	exit();
}

class public_awards_awards_awards extends ipsCommand
{
	public function doExecute(ipsRegistry $registry)
	{
		# Get the language
		$this->lang->loadLanguageFile(array("public_awards"), 'awards');
		
		# Title and navigation
		$this->registry->output->setTitle($this->lang->words['title']);
		$this->registry->output->addNavigation($this->lang->words['title'], "app=awards&module=awards&section=awards");
		
		# Is this page enabled?
		if(!$this->settings['awds_system_status'])
		{
			# Is there a custom message to show?
			if($this->settings['awd_listings_disabled_msg'])
			{
				$msg = $this->settings['awd_listings_disabled_msg'];
			}
			else
			{
				$msg = $this->lang->words['error_listings_disabled'];
			}
			
			$this->registry->getClass('output')->showError($msg, "11A1", false);
		}
		
		switch($this->request['DO'])
		{
			case "award":
				$this->publicAward();
				break;
			case "remove":
				$this->publicRemove();
				break;
			default:
				$this->showListings();
				break;
		}
		
		# Copyright information - do not remove
		$this->registry->getClass('output')->addContent("<div align='right' style='font-size:10px; margin-top:10px;'>(inv) Awards " . INV_APP_VERSION . ", by <a href='http://www.invisionenvy.com/forums/' target='_blank'>Alec Carpenter</a></div>");
		
		# Finish it off
        $this->registry->output->sendOutput();
	}
	
	private function publicAward()
	{
		$memberData = IPSMember::load($this->request['mid']);
		
		if(!$this->registry->getClass('class_awards')->canPublic_Award($memberData) || $this->settings['awds_disable_public_awarding'])
		{
			$this->registry->getClass('output')->showError($this->lang->words['error_no_permission'], "11A4", false);
		}
		
		$this->registry->output->addNavigation($this->lang->words['give_award_title'] . " " . $memberData['members_display_name'], "");
		
		if($this->request['submit'])
		{
			$approved = 1;
			
			if($this->settings['awds_require_admin_approval'])
			{
				if(!$this->memberData['g_access_cp'])
				{
					if(strpos($this->settings['awds_admin_approval_exempt'] . ",", $this->memberData['member_group_id'] . ",") === FALSE)
					{
						$approved = 0;
					}
				}
			}
			
			$this->DB->insert('inv_awards_awarded', array(
														  'award_id'   => $_POST['award'],
														  'user_id'    => $memberData['member_id'],
														  'awarded_by' => $this->memberData['member_id'],
														  'approved'   => $approved,
														  'is_active'  => 1,
														  'notes'      => htmlentities($_POST['notes'], ENT_QUOTES),
														  'date'       => IPS_UNIX_TIME_NOW,
			));
			
			$url = ipsRegistry::getClass('output')->buildSEOUrl('showuser=' . $memberData['member_id'] . '&tab=awards', 'public', $memberData['members_seo_name'], 'showuser');
			
			$this->registry->getClass('output')->redirectScreen($this->lang->words['award_added'], $url);
		}
		
		$this->DB->build(array(
							   'select' => '*',
							   'from'   => 'inv_awards',
		));
		
		$this->DB->execute();
		
		while($a = $this->DB->fetch())
		{
			if(strpos($a['public_perms'], $this->memberData['member_group_id']) !== FALSE || !$a['public_perms'])
			{
				$options[$a['id']] = $a['name'];
			}
		}
		
		# Show Form
		$output .= $this->registry->output->getTemplate('awards')->giveAward_form($memberData, $options);
		
		# Put it out there!
		$this->registry->getClass('output')->addContent($output);
	}
	
	private function publicRemove()
	{
		if(!$this->memberData['g_can_remove_awards'] && !$this->memberData['g_access_cp'])
		{
			$this->registry->getClass('output')->showError($this->lang->words['error_no_permission'], "11A5", false);
		}
		
		if(!$this->memberData['g_access_cp'])
		{
			$furtherValidation = " && awarded_by = {$this->memberData['member_id']}";
		}
		
		$this->DB->build(array(
							   'select' => '*',
							   'from'   => 'inv_awards_awarded',
							   'where'  => 'row_id = ' . $this->request['id'] . $furtherValidation,
		));
		
		$this->DB->execute();
		
		if(!$this->DB->getTotalRows())
		{
			$this->registry->getClass('output')->showError($this->lang->words['error_invalid_request'], "11A6", false);
		}
		
		$a  = $this->DB->fetch();
		$am = IPSMember::load($a['user_id']);
		
		$approved = 1;
		if($this->settings['awds_admin_approve_removals'])
		{
			if(!$this->memberData['g_access_cp'])
			{
				if(strpos($this->settings['awds_admin_approval_exempt'] . ",", $this->memberData['member_group_id'] . ",") === FALSE)
				{
					$approved = 0;
				}
			}
		}
		
		if($approved)
		{
			$this->DB->delete('inv_awards_awarded', 'row_id = ' . $a['row_id']);
		}
		else
		{
			$this->DB->update('inv_awards_awarded', array(
														  'approved'  => '-1',
														  'is_active' => 0,
			), 'row_id = ' . $a['row_id']);
		}
		
		$url = ipsRegistry::getClass('output')->buildSEOUrl('showuser=' . $am['member_id'] . '&tab=awards', 'public', $am['members_seo_name'], 'showuser');
		
		$this->registry->getClass('output')->redirectScreen($this->lang->words['award_removed'], $url);
	}
	
	private function showListings()
	{
		# Does this user have permission
		if(!$this->verifyPermission())
		{
			$this->registry->getClass('output')->showError($this->lang->words['error_no_permission'], "11A3", false);
		}
		
		# Get categories
		$this->DB->build(array(
								'select'   => '*',
								'from'     => 'inv_awards_cats',
								'where'    => "`visible` = '1'",
								'order' => 'placement ASC',
		));
		
		$getCats = $this->DB->execute();
		
		while($c = $this->DB->fetch($getCats))
		{
			# Get awards to show
			$this->DB->build(array(
									'select'   => '*',
									'from'     => 'inv_awards',
									'where'    => "`visible` = '1' && `parent` = '{$c['cat_id']}'",
									'order' => 'placement ASC',
			));
			
			$getAwards = $this->DB->execute();
			$totalRows = 0;
			
			# Get'em ready!
			while($a = $this->DB->fetch($getAwards))
			{
				if(!$totalRows)
				{
					$start_cat = $c['title'];
				}
				
				if($totalRows&1)
				{
					$a['class'] = "row2";
				}
				else
				{
					$a['class'] = "row1";
				}
				
				$rows .= $this->registry->output->getTemplate('awards')->listings_row($a, $this->settings['upload_url'], $start_cat);
				
				unset($start_cat);
				$totalRows++;
			}
		}
			
		# Verify we have awards
		if(!$rows)
		{
			$this->registry->getClass('output')->showError($this->lang->words['error_no_awards'], "10A2", false);
		}
		
		# AJAX URL
		$output .= $this->registry->output->getTemplate('awards')->listings_container($rows);
		
		# Put it out there!
		$this->registry->getClass('output')->addContent($output);
	}
	
	function verifyPermission()
	{
		$perms = $this->settings['awds_permissions'];
		$exp   = explode(",", $perms);
		
		$p = FALSE;
		foreach($exp as $gid)
		{
			if($this->memberData['g_id'] == $gid)
			{
				$p = TRUE;
			}
		}
		
		return $p;
	}
}
?>